import asyncio
from loguru import logger
from easycache import easycache

cache1 = easycache.bind_redis('127.0.0.1', 6379)

@cache1.find(prefix='term', key_param_index=1)
async def ddd1(terminology_id):
    logger.info('read in db')
    await asyncio.sleep(3)
    return "ddd1 running"

def mulid(dir):
    return dir['list']

@cache1.delete(prefix='term', key_param_index=5)
async def ddd2(terminology_id):

    logger.info('funcing')
    await asyncio.sleep(1)
    return "ddd2 running"

@cache1.delete(prefix='term', key_param_index=1, get_multiple_key_func=mulid)
async def ddd3(tdis):
    logger.info('ddd3')
    await asyncio.sleep(1)
    return 'ddd3 running'

async def main():
    task_list = []
    task_list.append(asyncio.create_task(ddd1(1)))
    task_list.append(asyncio.create_task(ddd1('bbb')))
    task_list.append(asyncio.create_task(ddd1('ccc')))
    result = await asyncio.gather(*task_list)
    tmp = {'list':['aaa', 'bbb', 'ccc']}
    await asyncio.gather(asyncio.create_task(ddd3(tmp)))
    return result

result = asyncio.run(main())
print(result)


import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="rosetta-easycache",# Replace with your own username
    version="0.0.4",
    author="Zhiyuan Zhang",
    author_email="zhangzhiyuan1@joyy.com",
    description="一个快速使用异步redis优化数据库查询项目",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://git.duowan.com/ai/nlp/easy-cache",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
)


import json
import datetime
from bson import ObjectId


class DateEncoder(json.JSONEncoder):
    def default(self, obj):
        if isinstance(obj, datetime.datetime):
            if not obj.tzinfo:
                obj = obj.replace(tzinfo=datetime.timezone.utc)
            return obj.isoformat()
        elif isinstance(obj, datetime.date):
            return obj.strftime("%Y-%m-%d")
        elif isinstance(obj, ObjectId):
            return str(obj)
        else:
            return json.JSONEncoder.default(self, obj)